aboutsummaryrefslogtreecommitdiffstats
path: root/pugl/detail/types.h
diff options
context:
space:
mode:
Diffstat (limited to 'pugl/detail/types.h')
-rw-r--r--pugl/detail/types.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/pugl/detail/types.h b/pugl/detail/types.h
index 7b2934f..656c34d 100644
--- a/pugl/detail/types.h
+++ b/pugl/detail/types.h
@@ -96,11 +96,11 @@ struct PuglBackendImpl {
/** Destroy surface and drawing context. */
PuglStatus (*destroy)(PuglView*);
- /** Enter drawing context, for drawing if parameter is true. */
- PuglStatus (*enter)(PuglView*, bool);
+ /** Enter drawing context, for drawing if expose is non-null. */
+ PuglStatus (*enter)(PuglView*, const PuglEventExpose*);
- /** Leave drawing context, after drawing if parameter is true. */
- PuglStatus (*leave)(PuglView*, bool);
+ /** Leave drawing context, after drawing if expose is non-null. */
+ PuglStatus (*leave)(PuglView*, const PuglEventExpose*);
/** Resize drawing context to the given width and height. */
PuglStatus (*resize)(PuglView*, int, int);